# coding:utf-8
# author:eric(2384363842@qq.com)
# 创建于: 2018/10/24 19:55
from setuptools import setup
setup(
    name='eric_4_1809_py',         # 应用名
    version='1.0',        # 版本号
    packages=['eric_4_1809_python'],  # 包括在安装包内的Python包
    author="hustcsxg",
    author_email="hustcsxg@163.com",
    url="http://www.py2ai.com"
)